@@ -183,44 +183,88 @@ BaseTestCase is the superclass for all the backend(Non UI) and frontend(UI) Test
             self.logger.info("assert_is_not_none(%s)  -- Failed" % (actual_val))
             raise
 
-    def compare_json_and_return_diff(self, expected_json, actual_json):
+    def compare_json_and_return_diff(self, expected_json, actual_json, rules=None):
+        """
+        此方法 比较两个 json 时会忽略结构体内item的顺序,即如下 json1 & json2 会被认为是相同的
+        json1 = {
+            "name": "lintest",
+            "Company": {
+                "name": "IKEA",
+                "No": 1
+            },
+            "version": "1.0"
+        }
+        json2 = {
+            "version": "1.0",
+            "name": "lintest",
+            "Company": {
+                "name": "IKEA",
+                "No": 1
+            }
+        }
+        """
+
         self.logger.info(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> compare_json: ")
         self.logger.info("------ expected_json: ")
         self.logger.info(self.pformat(expected_json))
         self.logger.info("------ actual_json: ")
         self.logger.info(self.pformat(actual_json))
 
-        diff = Compare().check(expected_json, actual_json)
+        if rules:
+            self.logger.info("------ rules:")
+            self.logger.info(rules)
+
+        diff = Compare(rules=rules).check(expected_json, actual_json)
         self.logger.info("<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< compare_json diff: ")
         self.logger.info(self.pformat(diff))
 
         # 判断逻辑交给用户，这里直接返回diff
         return diff
 
-    def compare_json_and_assert_equal(self, expected_json, actual_json):
-        diff = self.compare_json_and_return_diff(expected_json, actual_json)
+    def compare_json_and_assert_equal(self, expected_json, actual_json, rules=None):
+        diff = self.compare_json_and_return_diff(expected_json, actual_json, rules)
         self.pprint(diff)
         assert diff == {}
 
-    def compare_json_ignore_order(self, expected_json, actual_json):
-        # 忽略json体内的顺序, 即认为： { "name": "lintest", "version": 1.0 }  和 {"version": 1.0, "name": "lintest" } 是等价的
+    def compare_json_with_strict_mode(self, expected_json, actual_json):
+        """不会忽略json体内Item的顺序, 即: { "name": "lintest", "version": 1.0 } 和 {"version": 1.0, "name": "lintest" } 是不同的, 本质上就是当做字符串来比较"""
+
+        self.logger.info(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> compare_json_with_strict_mode: ")
+        v1 = json.dumps(expected_json, sort_keys=False)
+        v2 = json.dumps(actual_json, sort_keys=False)
 
-        self.logger.info(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> compare_json_ignore_order: ")
         self.logger.info("------ expected_json: ")
-        self.logger.info(self.pformat(expected_json))
+        self.logger.info(self.pformat(v1))
+
         self.logger.info("------ actual_json: ")
-        self.logger.info(self.pformat(actual_json))
+        self.logger.info(self.pformat(v2))
 
-        # from collections import OrderedDict
-        # def sorting(item):
-        #     if isinstance(item, dict):
-        #         return sorted((key, sorting(values)) for key, values in item.items())
-        #     if isinstance(item, list):
-        #         return sorted(sorting(x) for x in item)
-        #     else:
-        #         return item
-        #
+        print("------ expected_json: ")
+        self.pprint(v1)
+        print("------ actual_json: ")
+        self.pprint(v2)
 
-        diff = self.compare_json_and_return_diff(json.loads(json.dumps(expected_json, sort_keys=True)),
-                                                 json.loads(json.dumps(actual_json, sort_keys=True)))
-        assert diff == {}
+        assert v1 == v2
+
+    # def compare_json_with_strict_mode(self, expected_json, actual_json):
+    #     """不会忽略json体内Item的顺序, 即: { "name": "lintest", "version": 1.0 } 和 {"version": 1.0, "name": "lintest" } 是不同的"""
+    #
+    #     self.logger.info(">>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>>> compare_json_with_strict_mode: ")
+    #     self.logger.info("------ expected_json: ")
+    #     self.logger.info(self.pformat(expected_json))
+    #     self.logger.info("------ actual_json: ")
+    #     self.logger.info(self.pformat(actual_json))
+    #
+    #     # from collections import OrderedDict
+    #     # def sorting(item):
+    #     #     if isinstance(item, dict):
+    #     #         return sorted((key, sorting(values)) for key, values in item.items())
+    #     #     if isinstance(item, list):
+    #     #         return sorted(sorting(x) for x in item)
+    #     #     else:
+    #     #         return item
+    #     #
+    #
+    #     diff = self.compare_json_and_return_diff(json.loads(json.dumps(expected_json, sort_keys=False)),
+    #                                              json.loads(json.dumps(actual_json, sort_keys=False)))
+    #     assert diff == {}
